# Python Handout

Turn your Python script into a handout with Markdown text and inline figures.
An alternative to notebooks without hidden state and using your own text
editor.

## Instructions

Installation:

```sh
pip3 install --user handout
```

Write a Python script or use `example.py` from above and run it. Then view the
resulting handout by opening `output/index.html` in a browser.

